@@ -3,47 +3,21 @@
 
 #include "spvm_native.h"
 
-#include <sys/stat.h>
-
 static const char* FILE_NAME = "Sys/IO/Windows.c";
 
 #if defined(_WIN32)
 
-#define _S_IFLNK ((unsigned)(_S_IFDIR | _S_IFCHR))
-
 // These implementations are originally copied form Perl win32/win32.c and win32/win32.h
 
+#include <sys/stat.h>
 #include <unistd.h>
 #include <windows.h>
 #include <errno.h>
 #include <winbase.h>
 #include <fcntl.h>
 
-#ifndef EDQUOT			/* Not in errno.h but wanted by POSIX.pm */
-#  define EDQUOT		WSAEDQUOT
-#endif
-
-#define dTHX 
-#define bool BOOL
-#define strEQ(string1, string2) (strcmp(string1, string2) == 0)
-#define isSLASH(c) ((c) == '/' || (c) == '\\')
-
-#define savepv(string) ((char*)env->get_chars(env, stack, env->new_string(env, stack, string, strlen(string))))
-
-#define SAVEFREEPV(pv) ((void*)NULL)
-
 static OSVERSIONINFO g_osver = {0, 0, 0, 0, 0, ""};
 
-typedef BOOLEAN (__stdcall *pCreateSymbolicLinkA_t)(LPCSTR, LPCSTR, DWORD);
-
-#ifndef SYMBOLIC_LINK_FLAG_DIRECTORY
-#  define SYMBOLIC_LINK_FLAG_DIRECTORY 0x1
-#endif
-
-#ifndef SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE
-#  define SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE 0x2
-#endif
-
 typedef struct {
     USHORT SubstituteNameOffset;
     USHORT SubstituteNameLength;
@@ -51,7 +25,7 @@ typedef struct {
     USHORT PrintNameLength;
     ULONG  Flags;
     WCHAR  PathBuffer[MAX_PATH*3];
-} MY_SYMLINK_REPARSE_BUFFER, *PMY_SYMLINK_REPARSE_BUFFER;
+} MY_SYMLINK_REPARSE_BUFFER;
 
 typedef struct {
     USHORT SubstituteNameOffset;
@@ -72,7 +46,26 @@ typedef struct {
       UCHAR DataBuffer[1];
     } GenericReparseBuffer;
   } Data;
-} MY_REPARSE_DATA_BUFFER, *PMY_REPARSE_DATA_BUFFER;
+} MY_REPARSE_DATA_BUFFER;
+
+#define _S_IFLNK ((unsigned)(_S_IFDIR | _S_IFCHR))
+
+#ifndef EDQUOT			/* Not in errno.h but wanted by POSIX.pm */
+#  define EDQUOT		WSAEDQUOT
+#endif
+
+#define strEQ(string1, string2) (strcmp(string1, string2) == 0)
+#define isSLASH(c) ((c) == '/' || (c) == '\\')
+
+#ifndef SYMBOLIC_LINK_FLAG_DIRECTORY
+#  define SYMBOLIC_LINK_FLAG_DIRECTORY 0x1
+#endif
+
+#ifndef SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE
+#  define SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE 0x2
+#endif
+
+typedef BOOLEAN (__stdcall *pCreateSymbolicLinkA_t)(LPCSTR, LPCSTR, DWORD);
 
 static BOOL
 is_symlink(HANDLE h) {
@@ -113,7 +106,6 @@ is_symlink_name(const char *name) {
 static int
 win32_unlink(const char *filename)
 {
-  dTHX;
   int ret;
   DWORD attrs;
   
@@ -147,7 +139,6 @@ win32_rename(const char *oname, const char *newname)
     char szOldName[MAX_PATH+1];
     BOOL bResult;
     DWORD dwFlags = MOVEFILE_COPY_ALLOWED;
-    dTHX;
     
     if (stricmp(newname, oname))
         dwFlags |= MOVEFILE_REPLACE_EXISTING;
@@ -225,7 +216,7 @@ translate_to_errno(void)
 }
 
 static int
-do_readlink_handle(HANDLE hlink, char *buf, size_t bufsiz, bool *is_symlink) {
+do_readlink_handle(HANDLE hlink, char *buf, size_t bufsiz, BOOL *is_symlink) {
     MY_REPARSE_DATA_BUFFER linkdata;
     DWORD linkdata_returned;
 
@@ -334,10 +325,9 @@ win32_readlink(const char *pathname, char *buf, size_t bufsiz) {
     return bytes_out;
 }
 
-int
+static int
 win32_symlink(SPVM_ENV* env, SPVM_VALUE* stack, const char *oldfile, const char *newfile)
 {
-    dTHX;
     size_t oldfile_len = strlen(oldfile);
     pCreateSymbolicLinkA_t pCreateSymbolicLinkA =
         (pCreateSymbolicLinkA_t)GetProcAddress(GetModuleHandle("kernel32.dll"), "CreateSymbolicLinkA");
@@ -360,8 +350,7 @@ win32_symlink(SPVM_ENV* env, SPVM_VALUE* stack, const char *oldfile, const char
         /* Win32 (or perhaps NTFS) won't follow symlinks containing
            /, so replace any with \\
         */
-        char *temp = savepv(oldfile);
-        SAVEFREEPV(temp);
+        char *temp = (char*)env->get_chars(env, stack, env->new_string(env, stack, oldfile, strlen(oldfile)));
         char *p = temp;
         while (*p) {
             if (*p == '/') {
@@ -441,7 +430,7 @@ win32_symlink(SPVM_ENV* env, SPVM_VALUE* stack, const char *oldfile, const char
     return 0;
 }
 
-int win32_lstat(const char* path, struct stat* sbuf)
+static int win32_lstat(const char* path, struct stat* sbuf)
 {
   HANDLE f;
   int result;
@@ -464,7 +453,7 @@ int win32_lstat(const char* path, struct stat* sbuf)
     return -1;
   }
   
-  bool is_symlink;
+  BOOL is_symlink;
   
   int size = do_readlink_handle(f, NULL, 0, &is_symlink);
   
